@@ -4,7 +4,7 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from . import (
+from botorch import (
     acquisition,
     exceptions,
     models,
@@ -13,17 +13,17 @@ from . import (
     settings,
     test_functions,
 )
-from .cross_validation import batch_cross_validation
-from .fit import fit_gpytorch_model
-from .generation.gen import (
+from botorch.cross_validation import batch_cross_validation
+from botorch.fit import fit_gpytorch_model
+from botorch.generation.gen import (
     gen_candidates_scipy,
     gen_candidates_torch,
     get_best_candidates,
 )
-from .utils import manual_seed
+from botorch.utils import manual_seed
 
 
-__version__ = "0.2.3"
+__version__ = "0.2.5"
 
 
 __all__ = [
