@@ -14,11 +14,10 @@ from __future__ import annotations
 from typing import List, Union
 
 import torch
+from botorch.acquisition.acquisition import AcquisitionFunction
 from torch import Tensor
 from torch.nn import Module
 
-from .acquisition import AcquisitionFunction
-
 
 class FixedFeatureAcquisitionFunction(AcquisitionFunction):
     """A wrapper around AquisitionFunctions to fix a subset of features.
