@@ -9,10 +9,9 @@ from __future__ import annotations
 from typing import Callable, Optional
 
 import torch
+from botorch.posteriors.posterior import Posterior
 from torch import Tensor
 
-from .posterior import Posterior
-
 
 class TransformedPosterior(Posterior):
     r"""An generic transformation of a posterior (implicitly represented)"""
