@@ -4,8 +4,12 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from .multi_fidelity import AugmentedBranin, AugmentedHartmann, AugmentedRosenbrock
-from .synthetic import (
+from botorch.test_functions.multi_fidelity import (
+    AugmentedBranin,
+    AugmentedHartmann,
+    AugmentedRosenbrock,
+)
+from botorch.test_functions.synthetic import (
     Ackley,
     Beale,
     Branin,
