@@ -15,11 +15,10 @@ from functools import wraps
 from typing import Any, Callable, List, Optional
 
 import torch
+from botorch import settings
 from gpytorch import settings as gpt_settings
 from torch import Tensor
 
-from .. import settings
-
 
 def squeeze_last_dim(Y: Tensor) -> Tensor:
     r"""Squeeze the last dimension of a Tensor.
@@ -227,7 +226,7 @@ def match_batch_shape(X: Tensor, Y: Tensor) -> Tensor:
         torch.Size([2, 6, 5, 3])
 
     """
-    return X.expand(X.shape[: -Y.dim()] + Y.shape[:-2] + X.shape[-2:])
+    return X.expand(X.shape[: -(Y.dim())] + Y.shape[:-2] + X.shape[-2:])
 
 
 def convert_to_target_pre_hook(module, *args):
